@@ -37,8 +37,15 @@ class EnvelopeElement(object):
 
 
 class CDARequest(object):
-    def __new__(cls, mensaje: CDA, as_string=True):
-        envelope = EnvelopeElement(BodyElement(CDAElement(mensaje.build_xml())))
-        if not as_string:
-            return envelope
-        return etree.tostring(envelope, xml_declaration=True)
+    def __init__(self, mensaje: CDA):
+        self._envelope = EnvelopeElement(BodyElement(CDAElement(mensaje.build_xml())))
+
+    @property
+    def tree(self):
+        return self._envelope
+
+    def to_string(self) -> bytes:
+        """
+        Returns the SOAP request as a string encoded in cp850 (bytes).
+        """
+        return etree.tostring(self._envelope, encoding='cp850', xml_declaration=True)
