@@ -1,6 +1,6 @@
 from typing import List
 
-from pydantic import BaseModel
+from pydantic.v1 import BaseModel
 
 from spei import types
 from spei.utils import to_snake_case  # noqa: WPS347
